diff --git a/Mage.Sets/src/mage/cards/a/ApproachOfTheSecondSun.java b/Mage.Sets/src/mage/cards/a/ApproachOfTheSecondSun.java
index 34e1ac8375..1877fee325 100644
--- a/Mage.Sets/src/mage/cards/a/ApproachOfTheSecondSun.java
+++ b/Mage.Sets/src/mage/cards/a/ApproachOfTheSecondSun.java
@@ -43,7 +43,7 @@ class ApproachOfTheSecondSunEffect extends OneShotEffect {
public ApproachOfTheSecondSunEffect() {
super(Outcome.Win);
this.staticText
- = "If {this} was cast from your hand and you've cast another spell named Approach of the Second Sun this game, you win the game. "
+ = "If this spell was cast from your hand and you've cast another spell named Approach of the Second Sun this game, you win the game. "
+ "Otherwise, put {this} into its owner's library seventh from the top and you gain 7 life.";
}
diff --git a/Mage.Sets/src/mage/cards/c/ChoArrimLegate.java b/Mage.Sets/src/mage/cards/c/ChoArrimLegate.java
index 95ba4e0204..22c24cc6b9 100644
--- a/Mage.Sets/src/mage/cards/c/ChoArrimLegate.java
+++ b/Mage.Sets/src/mage/cards/c/ChoArrimLegate.java
@@ -41,7 +41,7 @@ public final class ChoArrimLegate extends CardImpl {
// Protection from black
this.addAbility(ProtectionAbility.from(ObjectColor.BLACK));
- // If an opponent controls a Swamp and you control a Plains, you may cast Cho-Arrim Legate without paying its mana cost.
+ // If an opponent controls a Swamp and you control a Plains, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Swamp and you control a Plains",
new OpponentControlsPermanentCondition(filterSwamp),
new PermanentsOnTheBattlefieldCondition(filterPlains));
diff --git a/Mage.Sets/src/mage/cards/d/DacksDuplicate.java b/Mage.Sets/src/mage/cards/d/DacksDuplicate.java
index 3bed9903fb..646597f79c 100644
--- a/Mage.Sets/src/mage/cards/d/DacksDuplicate.java
+++ b/Mage.Sets/src/mage/cards/d/DacksDuplicate.java
@@ -32,9 +32,9 @@ public final class DacksDuplicate extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(0);
- // You may have Dack's Duplicate enter the battlefield as a copy of any creature on the battlefield except it gains haste and dethrone.
+ // You may have Dack's Duplicate enter the battlefield as a copy of any creature on the battlefield except it has haste and dethrone.
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, new DacksDuplicateApplyToPermanent());
- effect.setText("as a copy of any creature on the battlefield except it gains haste and dethrone");
+ effect.setText("as a copy of any creature on the battlefield except it has haste and dethrone");
this.addAbility(new EntersBattlefieldAbility(effect, true));
}
diff --git a/Mage.Sets/src/mage/cards/d/DeepwoodLegate.java b/Mage.Sets/src/mage/cards/d/DeepwoodLegate.java
index fc2be84121..d0dcb0ca4b 100644
--- a/Mage.Sets/src/mage/cards/d/DeepwoodLegate.java
+++ b/Mage.Sets/src/mage/cards/d/DeepwoodLegate.java
@@ -40,7 +40,7 @@ public final class DeepwoodLegate extends CardImpl {
this.power = new MageInt(1);
this.toughness = new MageInt(1);
- // If an opponent controls a Forest and you control a Swamp, you may cast Deepwood Legate without paying its mana cost.
+ // If an opponent controls a Forest and you control a Swamp, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Forest and you control a Swamp",
new OpponentControlsPermanentCondition(filterForest),
new PermanentsOnTheBattlefieldCondition(filterSwamp));
diff --git a/Mage.Sets/src/mage/cards/e/EvilTwin.java b/Mage.Sets/src/mage/cards/e/EvilTwin.java
index 339fcdbd07..51a77803e5 100644
--- a/Mage.Sets/src/mage/cards/e/EvilTwin.java
+++ b/Mage.Sets/src/mage/cards/e/EvilTwin.java
@@ -39,9 +39,9 @@ public final class EvilTwin extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(0);
- // You may have Evil Twin enter the battlefield as a copy of any creature on the battlefield except it gains "{U}{B}, {T}: Destroy target creature with the same name as this creature."
+ // You may have Evil Twin enter the battlefield as a copy of any creature on the battlefield, except it has "{U}{B}, {T}: Destroy target creature with the same name as this creature."
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, new EvilTwinApplyToPermanent());
- effect.setText("as a copy of any creature on the battlefield except it gains \"{U}{B}, {T}: Destroy target creature with the same name as this creature.\"");
+ effect.setText("as a copy of any creature on the battlefield, except it has \"{U}{B}, {T}: Destroy target creature with the same name as this creature.\"");
this.addAbility(new EntersBattlefieldAbility(effect, true));
}
diff --git a/Mage.Sets/src/mage/cards/g/Gigantoplasm.java b/Mage.Sets/src/mage/cards/g/Gigantoplasm.java
index 92e79d7f10..2b0eab220b 100644
--- a/Mage.Sets/src/mage/cards/g/Gigantoplasm.java
+++ b/Mage.Sets/src/mage/cards/g/Gigantoplasm.java
@@ -37,9 +37,9 @@ public final class Gigantoplasm extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(0);
- // You may have Gigantoplasm enter the battlefield as a copy of any creature on the battlefield except it gains "{X}: This creature has base power and toughness X/X."
+ // You may have Gigantoplasm enter the battlefield as a copy of any creature on the battlefield, except it has "{X}: This creature has base power and toughness X/X."
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, new GigantoplasmApplyToPermanent());
- effect.setText("a copy of any creature on the battlefield except it gains \"{X}: This creature has base power and toughness X/X.\"");
+ effect.setText("a copy of any creature on the battlefield, except it has \"{X}: This creature has base power and toughness X/X.\"");
this.addAbility(new EntersBattlefieldAbility(effect, true));
}
diff --git a/Mage.Sets/src/mage/cards/i/IncreasingVengeance.java b/Mage.Sets/src/mage/cards/i/IncreasingVengeance.java
index 33d22626e0..11e1d70dbb 100644
--- a/Mage.Sets/src/mage/cards/i/IncreasingVengeance.java
+++ b/Mage.Sets/src/mage/cards/i/IncreasingVengeance.java
@@ -38,7 +38,7 @@ public final class IncreasingVengeance extends CardImpl {
public IncreasingVengeance(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{R}{R}");
- // Copy target instant or sorcery spell you control. If Increasing Vengeance was cast from a graveyard, copy that spell twice instead. You may choose new targets for the copies.
+ // Copy target instant or sorcery spell you control. If this spell was cast from a graveyard, copy that spell twice instead. You may choose new targets for the copies.
this.getSpellAbility().addEffect(new IncreasingVengeanceEffect());
Target target = new TargetSpell(filter);
this.getSpellAbility().addTarget(target);
@@ -61,7 +61,7 @@ class IncreasingVengeanceEffect extends OneShotEffect {
public IncreasingVengeanceEffect() {
super(Outcome.BoostCreature);
- staticText = "Copy target instant or sorcery spell you control. If Increasing Vengeance was cast from a graveyard, copy that spell twice instead. You may choose new targets for the copies";
+ staticText = "Copy target instant or sorcery spell you control. If this spell was cast from a graveyard, copy that spell twice instead. You may choose new targets for the copies";
}
public IncreasingVengeanceEffect(final IncreasingVengeanceEffect effect) {
diff --git a/Mage.Sets/src/mage/cards/k/KyrenLegate.java b/Mage.Sets/src/mage/cards/k/KyrenLegate.java
index b77984d161..1c03329a93 100644
--- a/Mage.Sets/src/mage/cards/k/KyrenLegate.java
+++ b/Mage.Sets/src/mage/cards/k/KyrenLegate.java
@@ -39,7 +39,7 @@ public final class KyrenLegate extends CardImpl {
// Haste
this.addAbility(HasteAbility.getInstance());
- // If an opponent controls a Plains and you control a Mountain, you may cast Kyren Legate without paying its mana cost.
+ // If an opponent controls a Plains and you control a Mountain, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Plains and you control a Mountain",
new OpponentControlsPermanentCondition(filterPlains),
new PermanentsOnTheBattlefieldCondition(filterMountain));
diff --git a/Mage.Sets/src/mage/cards/m/Massacre.java b/Mage.Sets/src/mage/cards/m/Massacre.java
index 4d67f3550b..24af1a59d3 100644
--- a/Mage.Sets/src/mage/cards/m/Massacre.java
+++ b/Mage.Sets/src/mage/cards/m/Massacre.java
@@ -34,7 +34,7 @@ public final class Massacre extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{2}{B}{B}");
- // If an opponent controls a Plains and you control a Swamp, you may cast Massacre without paying its mana cost.
+ // If an opponent controls a Plains and you control a Swamp, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Plains and you control a Swamp",
new OpponentControlsPermanentCondition(filterPlains),
new PermanentsOnTheBattlefieldCondition(filterSwamp));
diff --git a/Mage.Sets/src/mage/cards/m/MercurialPretender.java b/Mage.Sets/src/mage/cards/m/MercurialPretender.java
index 12650ac73f..250feb98cb 100644
--- a/Mage.Sets/src/mage/cards/m/MercurialPretender.java
+++ b/Mage.Sets/src/mage/cards/m/MercurialPretender.java
@@ -23,7 +23,7 @@ import mage.util.functions.AbilityApplier;
*/
public final class MercurialPretender extends CardImpl {
- private static final String effectText = "as a copy of any creature you control except it gains \"{2}{U}{U}: Return this creature to its owner's hand.\"";
+ private static final String effectText = "as a copy of any creature you control, except it has \"{2}{U}{U}: Return this creature to its owner's hand.\"";
public MercurialPretender(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.CREATURE},"{4}{U}");
@@ -33,8 +33,8 @@ public final class MercurialPretender extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(0);
- // You may have Mercurial Pretender enter the battlefield as a copy of any creature you control
- // except it gains "{2}{U}{U}: Return this creature to its owner's hand."
+ // You may have Mercurial Pretender enter the battlefield as a copy of any creature you control,
+ // except it has "{2}{U}{U}: Return this creature to its owner's hand."
Effect effect = new CopyPermanentEffect(new FilterControlledCreaturePermanent(),
new AbilityApplier(new SimpleActivatedAbility(Zone.BATTLEFIELD, new ReturnToHandSourceEffect(true), new ManaCostsImpl("{2}{U}{U}"))));
effect.setText(effectText);
diff --git a/Mage.Sets/src/mage/cards/m/MinionReflector.java b/Mage.Sets/src/mage/cards/m/MinionReflector.java
index e792a5f431..a422664308 100644
--- a/Mage.Sets/src/mage/cards/m/MinionReflector.java
+++ b/Mage.Sets/src/mage/cards/m/MinionReflector.java
@@ -48,8 +48,8 @@ public final class MinionReflector extends CardImpl {
"entered the battlefield?"),
filter, false, SetTargetPointer.PERMANENT,
"Whenever a nontoken creature enters the battlefield under your control, " +
- "you may pay 2. If you do, create a token that's a copy of that creature. " +
- "That token has haste and \"At the beginning of the end step, sacrifice this " +
+ "you may pay 2. If you do, create a token that's a copy of that creature, " +
+ "except it has haste and \"At the beginning of the end step, sacrifice this " +
"permanent.\"");
this.addAbility(ability);
}
@@ -69,7 +69,7 @@ class MinionReflectorEffect extends OneShotEffect {
public MinionReflectorEffect() {
super(Outcome.PutCreatureInPlay);
- this.staticText = "create a token that's a copy of that creature. That token has haste and \"At the beginning of the end step, sacrifice this permanent.";
+ this.staticText = "create a token that's a copy of that creature, except it has haste and \"At the beginning of the end step, sacrifice this permanent.";
}
public MinionReflectorEffect(final MinionReflectorEffect effect) {
diff --git a/Mage.Sets/src/mage/cards/m/MoggSalvage.java b/Mage.Sets/src/mage/cards/m/MoggSalvage.java
index fed1f36fef..d45d5d2af7 100644
--- a/Mage.Sets/src/mage/cards/m/MoggSalvage.java
+++ b/Mage.Sets/src/mage/cards/m/MoggSalvage.java
@@ -33,7 +33,7 @@ public final class MoggSalvage extends CardImpl {
public MoggSalvage(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{2}{R}");
- // If an opponent controls an Island and you control a Mountain, you may cast Mogg Salvage without paying its mana cost.
+ // If an opponent controls an Island and you control a Mountain, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls an Island and you control a Mountain",
new OpponentControlsPermanentCondition(filterIsland),
new PermanentsOnTheBattlefieldCondition(filterMountain));
diff --git a/Mage.Sets/src/mage/cards/p/PatriciansScorn.java b/Mage.Sets/src/mage/cards/p/PatriciansScorn.java
index b8a7048837..0aed2b41de 100644
--- a/Mage.Sets/src/mage/cards/p/PatriciansScorn.java
+++ b/Mage.Sets/src/mage/cards/p/PatriciansScorn.java
@@ -31,7 +31,7 @@ public final class PatriciansScorn extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{3}{W}");
- // If you've cast another white spell this turn, you may cast Patrician's Scorn without paying its mana cost.
+ // If you've cast another white spell this turn, you may cast this spell without paying its mana cost.
this.addAbility(new AlternativeCostSourceAbility(new CastWhiteSpellThisTurnCondition()), new PatriciansScornWatcher());
// Destroy all enchantments.
this.getSpellAbility().addEffect(new DestroyAllEffect(StaticFilters.FILTER_ENCHANTMENT_PERMANENT));
@@ -87,7 +87,7 @@ class PatriciansScornWatcher extends Watcher {
@Override
public void watch(GameEvent event, Game game) {
- if (condition == true) { //no need to check - condition has already occured
+ if (condition) { //no need to check - condition has already occured
return;
}
if (event.getType() == EventType.SPELL_CAST && controllerId.equals(event.getPlayerId())) {
diff --git a/Mage.Sets/src/mage/cards/p/PhantasmalImage.java b/Mage.Sets/src/mage/cards/p/PhantasmalImage.java
index 383d66b238..003ff68f88 100644
--- a/Mage.Sets/src/mage/cards/p/PhantasmalImage.java
+++ b/Mage.Sets/src/mage/cards/p/PhantasmalImage.java
@@ -26,7 +26,7 @@ import java.util.UUID;
*/
public final class PhantasmalImage extends CardImpl {
- private static final String effectText = "a copy of any creature on the battlefield, except it's an Illusion in addition to its other types and it gains \"When this creature becomes the target of a spell or ability, sacrifice it.\"";
+ private static final String effectText = "a copy of any creature on the battlefield, except it's an Illusion in addition to its other types and it has \"When this creature becomes the target of a spell or ability, sacrifice it.\"";
ApplyToPermanent phantasmalImageApplier = new ApplyToPermanent() {
@Override
@@ -62,7 +62,7 @@ public final class PhantasmalImage extends CardImpl {
// You may have Phantasmal Image enter the battlefield as a copy of any creature
// on the battlefield, except it's an Illusion in addition to its other types and
- // it gains "When this creature becomes the target of a spell or ability, sacrifice it."
+ // it has "When this creature becomes the target of a spell or ability, sacrifice it."
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, phantasmalImageApplier);
effect.setText(effectText);
this.addAbility(new EntersBattlefieldAbility(effect, true));
diff --git a/Mage.Sets/src/mage/cards/p/ProgenitorMimic.java b/Mage.Sets/src/mage/cards/p/ProgenitorMimic.java
index b3a181e230..fec1160c10 100644
--- a/Mage.Sets/src/mage/cards/p/ProgenitorMimic.java
+++ b/Mage.Sets/src/mage/cards/p/ProgenitorMimic.java
@@ -40,7 +40,7 @@ public final class ProgenitorMimic extends CardImpl {
this.toughness = new MageInt(0);
// You may have Progenitor Mimic enter the battlefield as a copy of any creature on the battlefield
- // except it gains "At the beginning of your upkeep, if this creature isn't a token,
+ // except it has "At the beginning of your upkeep, if this creature isn't a token,
// create a token that's a copy of this creature."
Effect effect = new CreateTokenCopySourceEffect();
effect.setText("create a token that's a copy of this creature");
@@ -52,7 +52,7 @@ public final class ProgenitorMimic extends CardImpl {
"At the beginning of your upkeep, if this creature isn't a token, create a token that's a copy of this creature.")
);
effect = new CopyPermanentEffect(applier);
- effect.setText("as a copy of any creature on the battlefield except it gains \"At the beginning of your upkeep, if this creature isn't a token, create a token that's a copy of this creature.\"");
+ effect.setText("as a copy of any creature on the battlefield except it has \"At the beginning of your upkeep, if this creature isn't a token, create a token that's a copy of this creature.\"");
this.addAbility(new EntersBattlefieldAbility(effect, true));
}
diff --git a/Mage.Sets/src/mage/cards/r/RefreshingRain.java b/Mage.Sets/src/mage/cards/r/RefreshingRain.java
index 57fb9afe34..038c187b5a 100644
--- a/Mage.Sets/src/mage/cards/r/RefreshingRain.java
+++ b/Mage.Sets/src/mage/cards/r/RefreshingRain.java
@@ -33,7 +33,7 @@ public final class RefreshingRain extends CardImpl {
public RefreshingRain(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{3}{G}");
- // If an opponent controls a Swamp and you control a Forest, you may cast Refreshing Rain without paying its mana cost.
+ // If an opponent controls a Swamp and you control a Forest, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Swamp and you control a Forest",
new OpponentControlsPermanentCondition(filterSwamp),
new PermanentsOnTheBattlefieldCondition(filterForest));
diff --git a/Mage.Sets/src/mage/cards/r/RushwoodLegate.java b/Mage.Sets/src/mage/cards/r/RushwoodLegate.java
index fa6cac12a7..6267bdf3d5 100644
--- a/Mage.Sets/src/mage/cards/r/RushwoodLegate.java
+++ b/Mage.Sets/src/mage/cards/r/RushwoodLegate.java
@@ -35,7 +35,7 @@ public final class RushwoodLegate extends CardImpl {
this.power = new MageInt(2);
this.toughness = new MageInt(1);
- // If an opponent controls an Island and you control a Forest, you may cast Rushwood Legate without paying its mana cost.
+ // If an opponent controls an Island and you control a Forest, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls an Island and you control a Forest",
new OpponentControlsPermanentCondition(filterIsland),
new PermanentsOnTheBattlefieldCondition(filterForest));
diff --git a/Mage.Sets/src/mage/cards/s/SaprazzanLegate.java b/Mage.Sets/src/mage/cards/s/SaprazzanLegate.java
index a61a55454a..c0d57d7e59 100644
--- a/Mage.Sets/src/mage/cards/s/SaprazzanLegate.java
+++ b/Mage.Sets/src/mage/cards/s/SaprazzanLegate.java
@@ -32,15 +32,14 @@ public final class SaprazzanLegate extends CardImpl {
public SaprazzanLegate(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.CREATURE},"{3}{U}");
- this.subtype.add(SubType.MERFOLK);
- this.subtype.add(SubType.SOLDIER);
+ this.subtype.add(SubType.MERFOLK, SubType.SOLDIER);
this.power = new MageInt(1);
this.toughness = new MageInt(3);
// Flying
this.addAbility(FlyingAbility.getInstance());
- // If an opponent controls a Mountain and you control an Island, you may cast Saprazzan Legate without paying its mana cost.
+ // If an opponent controls a Mountain and you control an Island, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Mountain and you control an Island",
new OpponentControlsPermanentCondition(filterMountain),
new PermanentsOnTheBattlefieldCondition(filterIsland));
diff --git a/Mage.Sets/src/mage/cards/s/SivvisRuse.java b/Mage.Sets/src/mage/cards/s/SivvisRuse.java
index 96368787a7..0ebc135c69 100644
--- a/Mage.Sets/src/mage/cards/s/SivvisRuse.java
+++ b/Mage.Sets/src/mage/cards/s/SivvisRuse.java
@@ -34,7 +34,7 @@ public final class SivvisRuse extends CardImpl {
public SivvisRuse(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{2}{W}{W}");
- // If an opponent controls a Mountain and you control a Plains, you may cast Sivvi's Ruse without paying its mana cost.
+ // If an opponent controls a Mountain and you control a Plains, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Mountain and you control a Plains",
new OpponentControlsPermanentCondition(filterMountain),
new PermanentsOnTheBattlefieldCondition(filterPlains));
diff --git a/Mage.Sets/src/mage/cards/s/Submerge.java b/Mage.Sets/src/mage/cards/s/Submerge.java
index c8bf389e0c..aeacf5422e 100644
--- a/Mage.Sets/src/mage/cards/s/Submerge.java
+++ b/Mage.Sets/src/mage/cards/s/Submerge.java
@@ -34,7 +34,7 @@ public final class Submerge extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.INSTANT},"{4}{U}");
- // If an opponent controls a Forest and you control an Island, you may cast Submerge without paying its mana cost.
+ // If an opponent controls a Forest and you control an Island, you may cast this spell without paying its mana cost.
Condition condition = new CompoundCondition("If an opponent controls a Forest and you control an Island",
new OpponentControlsPermanentCondition(filterForest),
new PermanentsOnTheBattlefieldCondition(filterIsland));
diff --git a/Mage.Sets/src/mage/cards/t/TemptWithImmortality.java b/Mage.Sets/src/mage/cards/t/TemptWithImmortality.java
index e570ca2a7c..ad8c586bca 100644
--- a/Mage.Sets/src/mage/cards/t/TemptWithImmortality.java
+++ b/Mage.Sets/src/mage/cards/t/TemptWithImmortality.java
@@ -28,7 +28,7 @@ public final class TemptWithImmortality extends CardImpl {
public TemptWithImmortality(UUID ownerId, CardSetInfo setInfo) {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{4}{B}");
- // Tempting offer - Return a creature card from your graveyard to the battlefield. Each opponent may return a creature card from their graveyard to the battlefield. For each player who does, return a creature card from your graveyard to the battlefield.
+ // Tempting offer - Return a creature card from your graveyard to the battlefield. Each opponent may return a creature card from their graveyard to the battlefield. For each opponent who does, return a creature card from your graveyard to the battlefield.
this.getSpellAbility().addEffect(new TemptWithImmortalityEffect());
}
@@ -46,7 +46,7 @@ class TemptWithImmortalityEffect extends OneShotEffect {
public TemptWithImmortalityEffect() {
super(Outcome.PutCreatureInPlay);
- this.staticText = "Tempting offer — Return a creature card from your graveyard to the battlefield. Each opponent may return a creature card from their graveyard to the battlefield. For each player who does, return a creature card from your graveyard to the battlefield";
+ this.staticText = "Tempting offer — Return a creature card from your graveyard to the battlefield. Each opponent may return a creature card from their graveyard to the battlefield. For each opponent who does, return a creature card from your graveyard to the battlefield";
}
diff --git a/Mage.Sets/src/mage/cards/t/TemptWithVengeance.java b/Mage.Sets/src/mage/cards/t/TemptWithVengeance.java
index 1235583957..be648e61b6 100644
--- a/Mage.Sets/src/mage/cards/t/TemptWithVengeance.java
+++ b/Mage.Sets/src/mage/cards/t/TemptWithVengeance.java
@@ -23,7 +23,7 @@ public final class TemptWithVengeance extends CardImpl {
public TemptWithVengeance(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.SORCERY}, "{X}{R}");
- // Tempting offer - create X 1/1 red Elemental creature tokens with haste. Each opponent may create X 1/1 red Elemental creature tokens with haste. For each player who does, create X 1/1 red Elemental creature tokens with haste.
+ // Tempting offer - create X 1/1 red Elemental creature tokens with haste. Each opponent may create X 1/1 red Elemental creature tokens with haste. For each opponent who does, create X 1/1 red Elemental creature tokens with haste.
this.getSpellAbility().addEffect(new TemptWithVengeanceEffect());
}
@@ -41,7 +41,7 @@ class TemptWithVengeanceEffect extends OneShotEffect {
public TemptWithVengeanceEffect() {
super(Outcome.PutLandInPlay);
- this.staticText = "Tempting offer — create X 1/1 red Elemental creature tokens with haste. Each opponent may create X 1/1 red Elemental creature tokens with haste. For each player who does, create X 1/1 red Elemental creature tokens with haste";
+ this.staticText = "Tempting offer — create X 1/1 red Elemental creature tokens with haste. Each opponent may create X 1/1 red Elemental creature tokens with haste. For each opponent who does, create X 1/1 red Elemental creature tokens with haste";
}
public TemptWithVengeanceEffect(final TemptWithVengeanceEffect effect) {
diff --git a/Mage.Sets/src/mage/cards/v/VesuvanDoppelganger.java b/Mage.Sets/src/mage/cards/v/VesuvanDoppelganger.java
index e52d2b2506..540626721f 100644
--- a/Mage.Sets/src/mage/cards/v/VesuvanDoppelganger.java
+++ b/Mage.Sets/src/mage/cards/v/VesuvanDoppelganger.java
@@ -30,7 +30,7 @@ import mage.util.functions.ApplyToPermanent;
*/
public final class VesuvanDoppelganger extends CardImpl {
- private static final String rule = "You may have {this} enter the battlefield as a copy of any creature on the battlefield except it doesn't copy that creature's color and it gains \"At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color. If you do, this creature gains this ability.\"";
+ private static final String rule = "You may have {this} enter the battlefield as a copy of any creature on the battlefield except it doesn't copy that creature's color and it has \"At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color and it has this ability.\"";
public VesuvanDoppelganger(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.CREATURE}, "{3}{U}{U}");
@@ -38,7 +38,7 @@ public final class VesuvanDoppelganger extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(0);
- // You may have Vesuvan Doppelganger enter the battlefield as a copy of any creature on the battlefield except it doesn't copy that creature's color and it gains "At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color. If you do, this creature gains this ability."
+ // You may have Vesuvan Doppelganger enter the battlefield as a copy of any creature on the battlefield except it doesn't copy that creature's color and it has "At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color and it has this ability."
Ability ability = new SimpleStaticAbility(Zone.BATTLEFIELD, new EntersBattlefieldEffect(new VesuvanDoppelgangerCopyEffect(), rule, true));
this.addAbility(ability);
@@ -56,7 +56,7 @@ public final class VesuvanDoppelganger extends CardImpl {
class VesuvanDoppelgangerCopyEffect extends OneShotEffect {
- private static final String rule2 = "At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color. If you do, this creature gains this ability.";
+ private static final String rule2 = "At the beginning of your upkeep, you may have this creature become a copy of target creature except it doesn't copy that creature's color and it has this ability.";
public VesuvanDoppelgangerCopyEffect() {
super(Outcome.Copy);
diff --git a/Mage.Sets/src/mage/cards/v/VesuvanShapeshifter.java b/Mage.Sets/src/mage/cards/v/VesuvanShapeshifter.java
index 3e3124ca82..404b0334c3 100644
--- a/Mage.Sets/src/mage/cards/v/VesuvanShapeshifter.java
+++ b/Mage.Sets/src/mage/cards/v/VesuvanShapeshifter.java
@@ -58,7 +58,7 @@ public final class VesuvanShapeshifter extends CardImpl {
ability.setWorksFaceDown(false);
this.addAbility(ability);
- // and gains "At the beginning of your upkeep, you may turn this creature face down".
+ // and has "At the beginning of your upkeep, you may turn this creature face down".
effect = new VesuvanShapeshifterFaceDownEffect();
ability = new BeginningOfUpkeepTriggeredAbility(Zone.BATTLEFIELD, effect, TargetController.YOU, true);
this.addAbility(ability);
@@ -102,7 +102,7 @@ class VesuvanShapeshifterEffect extends OneShotEffect {
public VesuvanShapeshifterEffect() {
super(Outcome.Copy);
- staticText = "have {this} become a copy of a creature and gain this ability";
+ staticText = "have {this} become a copy of a creature, except it has this ability";
}
public VesuvanShapeshifterEffect(final VesuvanShapeshifterEffect effect) {
diff --git a/Mage/src/main/java/mage/abilities/costs/AlternativeCostSourceAbility.java b/Mage/src/main/java/mage/abilities/costs/AlternativeCostSourceAbility.java
index 97a8839384..fef3c1e04c 100644
--- a/Mage/src/main/java/mage/abilities/costs/AlternativeCostSourceAbility.java
+++ b/Mage/src/main/java/mage/abilities/costs/AlternativeCostSourceAbility.java
@@ -230,7 +230,7 @@ public class AlternativeCostSourceAbility extends StaticAbility implements Alter
if (condition == null || alternateCosts.size() == 1) {
sb.append(" rather than pay this spell's mana cost");
} else if (alternateCosts.isEmpty()) {
- sb.append("cast {this} without paying its mana cost");
+ sb.append("cast this spell without paying its mana cost");
}
sb.append('.');
if (numberCosts == 1 && remarkText != null) {
diff --git a/Mage.Sets/src/mage/cards/a/ArtisanOfForms.java b/Mage.Sets/src/mage/cards/a/ArtisanOfForms.java
index fb83369e99..ac415c8439 100644
--- a/Mage.Sets/src/mage/cards/a/ArtisanOfForms.java
+++ b/Mage.Sets/src/mage/cards/a/ArtisanOfForms.java
@@ -32,9 +32,9 @@ public final class ArtisanOfForms extends CardImpl {
this.power = new MageInt(1);
this.toughness = new MageInt(1);
// Heroic — Whenever you cast a spell that targets Artisan of Forms, you may have Artisan of Forms become a copy of target creature and gain this ability.
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, new ArtisanOfFormsApplyToPermanent(), true);
- effect.setText("have {this} become a copy of target creature and gain this ability");
+ effect.setText("have {this} become a copy of target creature, except it has this ability");
Ability ability = new HeroicAbility(effect, true);
ability.addTarget(new TargetCreaturePermanent());
this.addAbility(ability);
@@ -55,7 +55,7 @@ class ArtisanOfFormsApplyToPermanent extends ApplyToPermanent {
@Override
public boolean apply(Game game, MageObject mageObject, Ability source, UUID copyToObjectId) {
Effect effect = new CopyPermanentEffect(new ArtisanOfFormsApplyToPermanent());
- effect.setText("have {this} become a copy of target creature and gain this ability");
+ effect.setText("have {this} become a copy of target creature, except it has this ability");
mageObject.getAbilities().add(new HeroicAbility(effect, true));
return true;
}
@@ -63,7 +63,7 @@ class ArtisanOfFormsApplyToPermanent extends ApplyToPermanent {
@Override
public boolean apply(Game game, Permanent permanent, Ability source, UUID copyToObjectId) {
Effect effect = new CopyPermanentEffect(new ArtisanOfFormsApplyToPermanent());
- effect.setText("have {this} become a copy of target creature and gain this ability");
+ effect.setText("have {this} become a copy of target creature, except it has this ability");
permanent.addAbility(new HeroicAbility(effect, true), game);
return true;
}
@@ -32,9 +32,9 @@ public final class ArtisanOfForms extends CardImpl {
this.power = new MageInt(1);
this.toughness = new MageInt(1);
- // Heroic — Whenever you cast a spell that targets Artisan of Forms, you may have Artisan of Forms become a copy of target creature and gain this ability.
+ // Heroic — Whenever you cast a spell that targets Artisan of Forms, you may have Artisan of Forms become a copy of target creature, except it has this ability.
Effect effect = new CopyPermanentEffect(StaticFilters.FILTER_PERMANENT_CREATURE, new ArtisanOfFormsApplyToPermanent(), true);
diff --git a/Mage.Sets/src/mage/cards/c/CemeteryPuca.java b/Mage.Sets/src/mage/cards/c/CemeteryPuca.java
index 89b065aa71..37498a7238 100644
--- a/Mage.Sets/src/mage/cards/c/CemeteryPuca.java
+++ b/Mage.Sets/src/mage/cards/c/CemeteryPuca.java
@@ -36,7 +36,7 @@ public final class CemeteryPuca extends CardImpl {
this.power = new MageInt(1);
this.toughness = new MageInt(2);
// Whenever a creature dies, you may pay {1}. If you do, Cemetery Puca becomes a copy of that creature and gains this ability.
this.addAbility(new DiesCreatureTriggeredAbility(new DoIfCostPaid(new CemeteryPucaEffect(), new ManaCostsImpl("{1}")), false, new FilterCreaturePermanent("a creature"), true));
}
@@ -55,7 +55,7 @@ class CemeteryPucaEffect extends OneShotEffect {
public CemeteryPucaEffect() {
super(Outcome.Copy);
- staticText = " {this} becomes a copy of that creature and gains this ability";
+ staticText = " {this} becomes a copy of that creature, except it has this ability";
}
public CemeteryPucaEffect(final CemeteryPucaEffect effect) {
@@ -36,7 +36,7 @@ public final class CemeteryPuca extends CardImpl {
this.power = new MageInt(1);
this.toughness = new MageInt(2);
- // Whenever a creature dies, you may pay {1}. If you do, Cemetery Puca becomes a copy of that creature and gains this ability.
+ // Whenever a creature dies, you may pay {1}. If you do, Cemetery Puca becomes a copy of that creature, except it has this ability.
this.addAbility(new DiesCreatureTriggeredAbility(new DoIfCostPaid(new CemeteryPucaEffect(), new ManaCostsImpl("{1}")), false, new FilterCreaturePermanent("a creature"), true));
}
diff --git a/Mage.Sets/src/mage/cards/d/DimirDoppelganger.java b/Mage.Sets/src/mage/cards/d/DimirDoppelganger.java
index a70951a13d..388d4d7bfb 100644
--- a/Mage.Sets/src/mage/cards/d/DimirDoppelganger.java
+++ b/Mage.Sets/src/mage/cards/d/DimirDoppelganger.java
@@ -36,7 +36,7 @@ public final class DimirDoppelganger extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(2);
// {1}{U}{B}: Exile target creature card from a graveyard. Dimir Doppelganger becomes a copy of that card and gains this ability.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new DimirDoppelgangerEffect(), new ManaCostsImpl("{1}{U}{B}"));
ability.addTarget(new TargetCardInGraveyard(new FilterCreatureCard("creature card in a graveyard")));
this.addAbility(ability);
@@ -57,7 +57,7 @@ class DimirDoppelgangerEffect extends OneShotEffect {
DimirDoppelgangerEffect() {
super(Outcome.Copy);
- staticText = "Exile target creature card from a graveyard. {this} becomes a copy of that card and gains this ability";
+ staticText = "Exile target creature card from a graveyard. {this} becomes a copy of that card, except it has this ability";
}
DimirDoppelgangerEffect(final DimirDoppelgangerEffect effect) {
@@ -36,7 +36,7 @@ public final class DimirDoppelganger extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(2);
- // {1}{U}{B}: Exile target creature card from a graveyard. Dimir Doppelganger becomes a copy of that card and gains this ability.
+ // {1}{U}{B}: Exile target creature card from a graveyard. Dimir Doppelganger becomes a copy of that card, except it has this ability.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new DimirDoppelgangerEffect(), new ManaCostsImpl("{1}{U}{B}"));
ability.addTarget(new TargetCardInGraveyard(new FilterCreatureCard("creature card in a graveyard")));
diff --git a/Mage.Sets/src/mage/cards/d/DreamPillager.java b/Mage.Sets/src/mage/cards/d/DreamPillager.java
index ad7ca79d2e..e0eefc81fe 100644
--- a/Mage.Sets/src/mage/cards/d/DreamPillager.java
+++ b/Mage.Sets/src/mage/cards/d/DreamPillager.java
@@ -37,7 +37,7 @@ public final class DreamPillager extends CardImpl {
// Flying
this.addAbility(FlyingAbility.getInstance());
// Whenever Dream Pillager deals combat damage to a player, exile that many cards from the top of your library. Until end of turn, you may cast nonland cards exiled this way.
this.addAbility(new DreamPillagerTriggeredAbility());
}
@@ -84,7 +84,7 @@ class DreamPillagerTriggeredAbility extends TriggeredAbilityImpl {
@Override
public String getRule() {
- return "Whenever {this} deals combat damage to a player, exile that many cards from the top of your library. Until end of turn, you may cast nonland cards exiled this way.";
+ return "Whenever {this} deals combat damage to a player, exile that many cards from the top of your library. Until end of turn, you may cast nonland cards from among those exiled cards.";
}
}
@@ -92,7 +92,7 @@ class DreamPillagerEffect extends OneShotEffect {
public DreamPillagerEffect() {
super(Outcome.Benefit);
- this.staticText = "exile that many cards from the top of your library. Until end of turn, you may cast nonland cards exiled this way";
+ this.staticText = "exile that many cards from the top of your library. Until end of turn, you may cast nonland cards from among those exiled cards";
}
public DreamPillagerEffect(final DreamPillagerEffect effect) {
@@ -37,7 +37,7 @@ public final class DreamPillager extends CardImpl {
// Flying
this.addAbility(FlyingAbility.getInstance());
- // Whenever Dream Pillager deals combat damage to a player, exile that many cards from the top of your library. Until end of turn, you may cast nonland cards exiled this way.
+ // Whenever Dream Pillager deals combat damage to a player, exile that many cards from the top of your library. Until end of turn, you may cast nonland cards from among those exiled cards.
this.addAbility(new DreamPillagerTriggeredAbility());
}
diff --git a/Mage.Sets/src/mage/cards/h/HeatShimmer.java b/Mage.Sets/src/mage/cards/h/HeatShimmer.java
index 2f86cafcd4..e0e8cb79ca 100644
--- a/Mage.Sets/src/mage/cards/h/HeatShimmer.java
+++ b/Mage.Sets/src/mage/cards/h/HeatShimmer.java
@@ -27,7 +27,7 @@ public final class HeatShimmer extends CardImpl {
public HeatShimmer(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.SORCERY}, "{2}{R}");
// Create a token that's a copy of target creature. That token has haste and "At the beginning of the end step, exile this permanent."
this.getSpellAbility().addEffect(new HeatShimmerEffect());
this.getSpellAbility().addTarget(new TargetCreaturePermanent());
}
@@ -46,7 +46,7 @@ class HeatShimmerEffect extends OneShotEffect {
public HeatShimmerEffect() {
super(Outcome.Copy);
- this.staticText = "Create a token that's a copy of target creature. That token has haste and \"At the beginning of the end step, exile this permanent.\"";
+ this.staticText = "Create a token that's a copy of target creature, except it has haste and \"At the beginning of the end step, exile this permanent.\"";
}
public HeatShimmerEffect(final HeatShimmerEffect effect) {
@@ -27,7 +27,7 @@ public final class HeatShimmer extends CardImpl {
public HeatShimmer(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.SORCERY}, "{2}{R}");
- // Create a token that's a copy of target creature. That token has haste and "At the beginning of the end step, exile this permanent."
+ //Create a token that's a copy of target creature, except it has haste and "At the beginning of the end step, exile this permanent."
this.getSpellAbility().addEffect(new HeatShimmerEffect());
this.getSpellAbility().addTarget(new TargetCreaturePermanent());
diff --git a/Mage.Sets/src/mage/cards/i/IncreasingAmbition.java b/Mage.Sets/src/mage/cards/i/IncreasingAmbition.java
index 39dacafdb6..fc62cc74c3 100644
--- a/Mage.Sets/src/mage/cards/i/IncreasingAmbition.java
+++ b/Mage.Sets/src/mage/cards/i/IncreasingAmbition.java
@@ -30,7 +30,7 @@ public final class IncreasingAmbition extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{4}{B}");
// Search your library for a card and put that card into your hand. If Increasing Ambition was cast from a graveyard, instead search your library for two cards and put those cards into your hand. Then shuffle your library.
this.getSpellAbility().addEffect(new IncreasingAmbitionEffect());
// Flashback {7}{B}
@@ -51,7 +51,7 @@ class IncreasingAmbitionEffect extends SearchEffect {
public IncreasingAmbitionEffect() {
super(new TargetCardInLibrary(), Outcome.DrawCard);
- staticText = "Search your library for a card and put that card into your hand. If {this} was cast from a graveyard, instead search your library for two cards and put those cards into your hand. Then shuffle your library";
+ staticText = "Search your library for a card and put that card into your hand. If this spell was cast from a graveyard, instead search your library for two cards and put those cards into your hand. Then shuffle your library";
}
public IncreasingAmbitionEffect(final IncreasingAmbitionEffect effect) {
@@ -30,7 +30,7 @@ public final class IncreasingAmbition extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{4}{B}");
- // Search your library for a card and put that card into your hand. If Increasing Ambition was cast from a graveyard, instead search your library for two cards and put those cards into your hand. Then shuffle your library.
+ // Search your library for a card and put that card into your hand. If this spell was cast from a graveyard, instead search your library for two cards and put those cards into your hand. Then shuffle your library.
this.getSpellAbility().addEffect(new IncreasingAmbitionEffect());
// Flashback {7}{B}
diff --git a/Mage.Sets/src/mage/cards/i/IncreasingConfusion.java b/Mage.Sets/src/mage/cards/i/IncreasingConfusion.java
index d3016def50..909f4ec7c0 100644
--- a/Mage.Sets/src/mage/cards/i/IncreasingConfusion.java
+++ b/Mage.Sets/src/mage/cards/i/IncreasingConfusion.java
@@ -24,7 +24,7 @@ public final class IncreasingConfusion extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{X}{U}");
// Target player puts the top X cards of their library into their graveyard. If Increasing Confusion was cast from a graveyard, that player puts twice that many cards into their graveyard instead.
this.getSpellAbility().addEffect(new IncreasingConfusionEffect());
this.getSpellAbility().addTarget(new TargetPlayer());
@@ -46,7 +46,7 @@ class IncreasingConfusionEffect extends OneShotEffect {
public IncreasingConfusionEffect() {
super(Outcome.Detriment);
- staticText = "Target player puts the top X cards of their library into their graveyard. If {this} was cast from a graveyard, that player puts twice that many cards into their graveyard instead";
+ staticText = "Target player puts the top X cards of their library into their graveyard. If this spell was cast from a graveyard, that player puts twice that many cards into their graveyard instead";
}
public IncreasingConfusionEffect(final IncreasingConfusionEffect effect) {
@@ -24,7 +24,7 @@ public final class IncreasingConfusion extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{X}{U}");
- // Target player puts the top X cards of their library into their graveyard. If Increasing Confusion was cast from a graveyard, that player puts twice that many cards into their graveyard instead.
+ // Target player puts the top X cards of their library into their graveyard. If this spell was cast from a graveyard, that player puts twice that many cards into their graveyard instead.
this.getSpellAbility().addEffect(new IncreasingConfusionEffect());
this.getSpellAbility().addTarget(new TargetPlayer());
diff --git a/Mage.Sets/src/mage/cards/i/IncreasingDevotion.java b/Mage.Sets/src/mage/cards/i/IncreasingDevotion.java
index 757ab3cbd3..2c21166797 100644
--- a/Mage.Sets/src/mage/cards/i/IncreasingDevotion.java
+++ b/Mage.Sets/src/mage/cards/i/IncreasingDevotion.java
@@ -25,7 +25,7 @@ public final class IncreasingDevotion extends CardImpl {
public IncreasingDevotion(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.SORCERY}, "{3}{W}{W}");
// Create five 1/1 white Human creature tokens. If Increasing Devotion was cast from a graveyard, create ten of those tokens instead.
this.getSpellAbility().addEffect(new IncreasingDevotionEffect());
// Flashback {7}{W}{W}
@@ -48,7 +48,7 @@ class IncreasingDevotionEffect extends OneShotEffect {
public IncreasingDevotionEffect() {
super(Outcome.PutCreatureInPlay);
- staticText = "Create five 1/1 white Human creature tokens. If {this} was cast from a graveyard, create ten of those tokens instead";
+ staticText = "Create five 1/1 white Human creature tokens. If this spell was cast from a graveyard, create ten of those tokens instead";
}
public IncreasingDevotionEffect(final IncreasingDevotionEffect effect) {
@@ -25,7 +25,7 @@ public final class IncreasingDevotion extends CardImpl {
public IncreasingDevotion(UUID ownerId, CardSetInfo setInfo) {
super(ownerId, setInfo, new CardType[]{CardType.SORCERY}, "{3}{W}{W}");
- // Create five 1/1 white Human creature tokens. If Increasing Devotion was cast from a graveyard, create ten of those tokens instead.
+ // Create five 1/1 white Human creature tokens. If this spell was cast from a graveyard, create ten of those tokens instead.
this.getSpellAbility().addEffect(new IncreasingDevotionEffect());
// Flashback {7}{W}{W}
diff --git a/Mage.Sets/src/mage/cards/i/IncreasingSavagery.java b/Mage.Sets/src/mage/cards/i/IncreasingSavagery.java
index 898083bedc..82cf03b321 100644
--- a/Mage.Sets/src/mage/cards/i/IncreasingSavagery.java
+++ b/Mage.Sets/src/mage/cards/i/IncreasingSavagery.java
@@ -25,7 +25,7 @@ public final class IncreasingSavagery extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{2}{G}{G}");
// Put five +1/+1 counters on target creature. If Increasing Savagery was cast from a graveyard, put ten +1/+1 counters on that creature instead.
this.getSpellAbility().addEffect(new IncreasingSavageryEffect());
this.getSpellAbility().addTarget(new TargetCreaturePermanent());
@@ -47,7 +47,7 @@ class IncreasingSavageryEffect extends OneShotEffect {
public IncreasingSavageryEffect() {
super(Outcome.BoostCreature);
- staticText = "Put five +1/+1 counters on target creature. If Increasing Savagery was cast from a graveyard, put ten +1/+1 counters on that creature instead";
+ staticText = "Put five +1/+1 counters on target creature. If this spell was cast from a graveyard, put ten +1/+1 counters on that creature instead";
}
public IncreasingSavageryEffect(final IncreasingSavageryEffect effect) {
@@ -25,7 +25,7 @@ public final class IncreasingSavagery extends CardImpl {
super(ownerId,setInfo,new CardType[]{CardType.SORCERY},"{2}{G}{G}");
- // Put five +1/+1 counters on target creature. If Increasing Savagery was cast from a graveyard, put ten +1/+1 counters on that creature instead.
+ // Put five +1/+1 counters on target creature. If this spell was cast from a graveyard, put ten +1/+1 counters on that creature instead.
this.getSpellAbility().addEffect(new IncreasingSavageryEffect());
this.getSpellAbility().addTarget(new TargetCreaturePermanent());
diff --git a/Mage.Sets/src/mage/cards/k/KikiJikiMirrorBreaker.java b/Mage.Sets/src/mage/cards/k/KikiJikiMirrorBreaker.java
index bc30f9246a..5b0bd8e301 100644
--- a/Mage.Sets/src/mage/cards/k/KikiJikiMirrorBreaker.java
+++ b/Mage.Sets/src/mage/cards/k/KikiJikiMirrorBreaker.java
@@ -49,7 +49,7 @@ public final class KikiJikiMirrorBreaker extends CardImpl {
// Haste
this.addAbility(HasteAbility.getInstance());
// {tap}: Create a token that's a copy of target nonlegendary creature you control . That token has haste. Sacrifice it at the beginning of the next end step.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new KikiJikiMirrorBreakerEffect(), new TapSourceCost());
ability.addTarget(new TargetControlledCreaturePermanent(1, 1, filter, false));
this.addAbility(ability);
@@ -70,7 +70,7 @@ class KikiJikiMirrorBreakerEffect extends OneShotEffect {
public KikiJikiMirrorBreakerEffect() {
super(Outcome.PutCreatureInPlay);
- this.staticText = "Create a token that's a copy of target nonlegendary creature you control. That token has haste. Sacrifice it at the beginning of the next end step";
+ this.staticText = "Create a token that's a copy of target nonlegendary creature you control, except it has haste. Sacrifice it at the beginning of the next end step";
}
public KikiJikiMirrorBreakerEffect(final KikiJikiMirrorBreakerEffect effect) {
@@ -49,7 +49,7 @@ public final class KikiJikiMirrorBreaker extends CardImpl {
// Haste
this.addAbility(HasteAbility.getInstance());
- // {tap}: Create a token that's a copy of target nonlegendary creature you control . That token has haste. Sacrifice it at the beginning of the next end step.
+ // {tap}: Create a token that's a copy of target nonlegendary creature you control, except it has haste. Sacrifice it at the beginning of the next end step.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new KikiJikiMirrorBreakerEffect(), new TapSourceCost());
ability.addTarget(new TargetControlledCreaturePermanent(1, 1, filter, false));
diff --git a/Mage.Sets/src/mage/cards/m/MizziumTransreliquat.java b/Mage.Sets/src/mage/cards/m/MizziumTransreliquat.java
index 149bef4fc2..298c2f4d8d 100644
--- a/Mage.Sets/src/mage/cards/m/MizziumTransreliquat.java
+++ b/Mage.Sets/src/mage/cards/m/MizziumTransreliquat.java
@@ -31,7 +31,7 @@ public final class MizziumTransreliquat extends CardImpl {
ability.addTarget(new TargetArtifactPermanent());
this.addAbility(ability);
// {1}{U}{R}: Mizzium Transreliquat becomes a copy of target artifact and gains this ability.
ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new MizziumTransreliquatCopyAndGainAbilityEffect(), new ManaCostsImpl("{1}{U}{R}"));
ability.addTarget(new TargetArtifactPermanent());
this.addAbility(ability);
@@ -79,7 +79,7 @@ class MizziumTransreliquatCopyAndGainAbilityEffect extends OneShotEffect {
public MizziumTransreliquatCopyAndGainAbilityEffect() {
super(Outcome.Benefit);
- this.staticText = "{this} becomes a copy of target artifact and gains this ability";
+ this.staticText = "{this} becomes a copy of target artifact, except it has this ability";
}
public MizziumTransreliquatCopyAndGainAbilityEffect(final MizziumTransreliquatCopyAndGainAbilityEffect effect) {
@@ -31,7 +31,7 @@ public final class MizziumTransreliquat extends CardImpl {
ability.addTarget(new TargetArtifactPermanent());
this.addAbility(ability);
- // {1}{U}{R}: Mizzium Transreliquat becomes a copy of target artifact and gains this ability.
+ // {1}{U}{R}: Mizzium Transreliquat becomes a copy of target artifact, except it has this ability.
ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new MizziumTransreliquatCopyAndGainAbilityEffect(), new ManaCostsImpl("{1}{U}{R}"));
ability.addTarget(new TargetArtifactPermanent());
diff --git a/Mage.Sets/src/mage/cards/s/SplinterTwin.java b/Mage.Sets/src/mage/cards/s/SplinterTwin.java
index 4ced5c998c..cd942fa669 100644
--- a/Mage.Sets/src/mage/cards/s/SplinterTwin.java
+++ b/Mage.Sets/src/mage/cards/s/SplinterTwin.java
@@ -43,7 +43,7 @@ public final class SplinterTwin extends CardImpl {
this.getSpellAbility().addEffect(new AttachEffect(Outcome.AddAbility));
Ability ability = new EnchantAbility(auraTarget.getTargetName());
this.addAbility(ability);
// Enchanted creature has "{tap}: Create a token that's a copy of this creature. That token has haste. Exile it at the beginning of the next end step."
SimpleActivatedAbility gainedAbility = new SimpleActivatedAbility(Zone.BATTLEFIELD, new SplinterTwinEffect(), new TapSourceCost());
this.addAbility(new SimpleStaticAbility(Zone.BATTLEFIELD, new GainAbilityAttachedEffect(gainedAbility, AttachmentType.AURA)));
}
@@ -62,7 +62,7 @@ class SplinterTwinEffect extends OneShotEffect {
public SplinterTwinEffect() {
super(Outcome.PutCreatureInPlay);
- this.staticText = "Create a token that's a copy of this creature. That token has haste. Exile it at the beginning of the next end step";
+ this.staticText = "Create a token that's a copy of this creature, except it has haste. Exile it at the beginning of the next end step";
}
public SplinterTwinEffect(final SplinterTwinEffect effect) {
@@ -43,7 +43,7 @@ public final class SplinterTwin extends CardImpl {
Ability ability = new EnchantAbility(auraTarget.getTargetName());
this.addAbility(ability);
- // Enchanted creature has "{tap}: Create a token that's a copy of this creature. That token has haste. Exile it at the beginning of the next end step."
+ // Enchanted creature has "{tap}: Create a token that's a copy of this creature, except it has haste. Exile it at the beginning of the next end step."
SimpleActivatedAbility gainedAbility = new SimpleActivatedAbility(Zone.BATTLEFIELD, new SplinterTwinEffect(), new TapSourceCost());
this.addAbility(new SimpleStaticAbility(Zone.BATTLEFIELD, new GainAbilityAttachedEffect(gainedAbility, AttachmentType.AURA)));
diff --git a/Mage.Sets/src/mage/cards/t/ThespiansStage.java b/Mage.Sets/src/mage/cards/t/ThespiansStage.java
index 58bd72d881..5b9ca21040 100644
--- a/Mage.Sets/src/mage/cards/t/ThespiansStage.java
+++ b/Mage.Sets/src/mage/cards/t/ThespiansStage.java
@@ -30,7 +30,7 @@ public final class ThespiansStage extends CardImpl {
// {T}: Add 1.
this.addAbility(new ColorlessManaAbility());
// 2, {T}: Thespian's Stage becomes a copy of target land and gains this ability.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new ThespiansStageCopyEffect(), new GenericManaCost(2));
ability.addCost(new TapSourceCost());
ability.addTarget(new TargetLandPermanent());
@@ -52,7 +52,7 @@ class ThespiansStageCopyEffect extends OneShotEffect {
public ThespiansStageCopyEffect() {
super(Outcome.Benefit);
- this.staticText = "{this} becomes a copy of target land and gains this ability";
+ this.staticText = "{this} becomes a copy of target land, except it has this ability";
}
public ThespiansStageCopyEffect(final ThespiansStageCopyEffect effect) {
@@ -30,7 +30,7 @@ public final class ThespiansStage extends CardImpl {
// {T}: Add 1.
this.addAbility(new ColorlessManaAbility());
- // 2, {T}: Thespian's Stage becomes a copy of target land and gains this ability.
+ // 2, {T}: Thespian's Stage becomes a copy of target land, except it has this ability.
Ability ability = new SimpleActivatedAbility(Zone.BATTLEFIELD, new ThespiansStageCopyEffect(), new GenericManaCost(2));
ability.addCost(new TapSourceCost());
diff --git a/Mage.Sets/src/mage/cards/t/Twinflame.java b/Mage.Sets/src/mage/cards/t/Twinflame.java
index ecc4f8dade..c1f6f7cd67 100644
--- a/Mage.Sets/src/mage/cards/t/Twinflame.java
+++ b/Mage.Sets/src/mage/cards/t/Twinflame.java
@@ -35,7 +35,7 @@ public final class Twinflame extends CardImpl {
// Strive - Twinflame costs 2R more to cast for each target beyond the first.
this.addAbility(new StriveAbility("{2}{R}"));
// Choose any number of target creatures you control. For each of them, create a token that's a copy of that creature. Those tokens have haste. Exile them at the beginning of the next end step.
this.getSpellAbility().addEffect(new TwinflameCopyEffect());
this.getSpellAbility().addTarget(new TargetControlledCreaturePermanent(0, Integer.MAX_VALUE, new FilterControlledCreaturePermanent(), false));
@@ -55,7 +55,7 @@ class TwinflameCopyEffect extends OneShotEffect {
public TwinflameCopyEffect() {
super(Outcome.PutCreatureInPlay);
- this.staticText = "Choose any number of target creatures you control. For each of them, create a token that's a copy of that creature. Those tokens have haste. Exile them at the beginning of the next end step";
+ this.staticText = "Choose any number of target creatures you control. For each of them, create a token that's a copy of that creature, except it has haste. Exile them at the beginning of the next end step";
}
public TwinflameCopyEffect(final TwinflameCopyEffect effect) {
@@ -35,7 +35,7 @@ public final class Twinflame extends CardImpl {
// Strive - Twinflame costs 2R more to cast for each target beyond the first.
this.addAbility(new StriveAbility("{2}{R}"));
- // Choose any number of target creatures you control. For each of them, create a token that's a copy of that creature. Those tokens have haste. Exile them at the beginning of the next end step.
+ // Choose any number of target creatures you control. For each of them, create a token that's a copy of that creature, except it has haste. Exile them at the beginning of the next end step.
this.getSpellAbility().addEffect(new TwinflameCopyEffect());
this.getSpellAbility().addTarget(new TargetControlledCreaturePermanent(0, Integer.MAX_VALUE, new FilterControlledCreaturePermanent(), false));
diff --git a/Mage.Sets/src/mage/cards/u/UnstableShapeshifter.java b/Mage.Sets/src/mage/cards/u/UnstableShapeshifter.java
index 9372d88744..99bf874862 100644
--- a/Mage.Sets/src/mage/cards/u/UnstableShapeshifter.java
+++ b/Mage.Sets/src/mage/cards/u/UnstableShapeshifter.java
@@ -40,7 +40,7 @@ public final class UnstableShapeshifter extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(1);
// Whenever another creature enters the battlefield, Unstable Shapeshifter becomes a copy of that creature and gains this ability.
this.addAbility(new EntersBattlefieldAllTriggeredAbility(Zone.BATTLEFIELD, new UnstableShapeshifterEffect(), filterAnotherCreature, false, SetTargetPointer.PERMANENT, ""));
}
@@ -58,7 +58,7 @@ class UnstableShapeshifterEffect extends OneShotEffect {
public UnstableShapeshifterEffect() {
super(Outcome.Copy);
- this.staticText = "{this} becomes a copy of that creature and gains this ability";
+ this.staticText = "{this} becomes a copy of that creature, except it has this ability";
}
public UnstableShapeshifterEffect(final UnstableShapeshifterEffect effect) {
@@ -40,7 +40,7 @@ public final class UnstableShapeshifter extends CardImpl {
this.power = new MageInt(0);
this.toughness = new MageInt(1);
- // Whenever another creature enters the battlefield, Unstable Shapeshifter becomes a copy of that creature and gains this ability.
+ // Whenever another creature enters the battlefield, Unstable Shapeshifter becomes a copy of that creature, except it has this ability.
this.addAbility(new EntersBattlefieldAllTriggeredAbility(Zone.BATTLEFIELD, new UnstableShapeshifterEffect(), filterAnotherCreature, false, SetTargetPointer.PERMANENT, ""));
}
diff --git a/Mage/src/main/java/mage/abilities/effects/common/CreateTokenCopyTargetEffect.java b/Mage/src/main/java/mage/abilities/effects/common/CreateTokenCopyTargetEffect.java
index 8bb428ddb1..40936884ef 100644
--- a/Mage/src/main/java/mage/abilities/effects/common/CreateTokenCopyTargetEffect.java
+++ b/Mage/src/main/java/mage/abilities/effects/common/CreateTokenCopyTargetEffect.java
@@ -33,7 +33,7 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
private final UUID playerId;
private final CardType additionalCardType;
- private boolean gainsHaste;
+ private boolean hasHaste;
private final int number;
private List addedTokenPermanents;
private SubType additionalSubType;
@@ -62,12 +62,12 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
this(playerId, null, false);
}
- public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean gainsHaste) {
- this(playerId, additionalCardType, gainsHaste, 1);
+ public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean hasHaste) {
+ this(playerId, additionalCardType, hasHaste, 1);
}
- public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean gainsHaste, int number) {
- this(playerId, additionalCardType, gainsHaste, number, false, false);
+ public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean hasHaste, int number) {
+ this(playerId, additionalCardType, hasHaste, number, false, false);
}
/**
@@ -75,24 +75,24 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
* @param playerId null the token is controlled/owned by the controller of
* the source ability
* @param additionalCardType the token gains this card type in addition
* @param gainsHaste the token gains haste
* @param number number of tokens to put into play
* @param tapped
* @param attacking
*/
- public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean gainsHaste, int number, boolean tapped, boolean attacking) {
- this(playerId, additionalCardType, gainsHaste, number, tapped, attacking, null);
+ public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean hasHaste, int number, boolean tapped, boolean attacking) {
+ this(playerId, additionalCardType, hasHaste, number, tapped, attacking, null);
}
- public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean gainsHaste, int number, boolean tapped, boolean attacking, UUID attackedPlayer) {
- this(playerId, additionalCardType, gainsHaste, number, tapped, attacking, attackedPlayer, Integer.MIN_VALUE, Integer.MIN_VALUE, false);
+ public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean hasHaste, int number, boolean tapped, boolean attacking, UUID attackedPlayer) {
+ this(playerId, additionalCardType, hasHaste, number, tapped, attacking, attackedPlayer, Integer.MIN_VALUE, Integer.MIN_VALUE, false);
}
- public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean gainsHaste, int number, boolean tapped, boolean attacking, UUID attackedPlayer, int power, int toughness, boolean gainsFlying) {
+ public CreateTokenCopyTargetEffect(UUID playerId, CardType additionalCardType, boolean hasHaste, int number, boolean tapped, boolean attacking, UUID attackedPlayer, int power, int toughness, boolean gainsFlying) {
super(Outcome.PutCreatureInPlay);
this.playerId = playerId;
this.additionalCardType = additionalCardType;
- this.gainsHaste = gainsHaste;
+ this.hasHaste = hasHaste;
this.addedTokenPermanents = new ArrayList<>();
this.number = number;
this.tapped = tapped;
@@ -107,7 +107,7 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
super(effect);
this.playerId = effect.playerId;
this.additionalCardType = effect.additionalCardType;
- this.gainsHaste = effect.gainsHaste;
+ this.hasHaste = effect.hasHaste;
this.addedTokenPermanents = new ArrayList<>(effect.addedTokenPermanents);
this.number = effect.number;
this.additionalSubType = effect.additionalSubType;
@@ -187,7 +187,7 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
if (additionalCardType != null && !token.getCardType().contains(additionalCardType)) {
token.addCardType(additionalCardType);
}
- if (gainsHaste) {
+ if (hasHaste) {
token.addAbility(HasteAbility.getInstance());
}
if (gainsFlying) {
@@ -75,24 +75,24 @@ public class CreateTokenCopyTargetEffect extends OneShotEffect {
* the source ability
* @param additionalCardType the token gains this card type in addition
- * @param gainsHaste the token gains haste
+ * @param hasHaste the token gains haste
* @param number number of tokens to put into play
* @param tapped